@@ -56,12 +56,14 @@ func encodeOperator(d *dataTreeNavigator, context Context, expressionNode *Expre
 		}
 
 		// dont print a new line when printing json on a single line.
-		if preferences.format == JsonOutputFormat && preferences.indent == 0 {
+		if (preferences.format == JsonOutputFormat && preferences.indent == 0) ||
+			preferences.format == CsvOutputFormat ||
+			preferences.format == TsvOutputFormat {
 			stringValue = chomper.ReplaceAllString(stringValue, "")
 		}
 
 		stringContentNode := &yaml.Node{Kind: yaml.ScalarNode, Tag: "!!str", Value: stringValue}
-		results.PushBack(candidate.CreateChild(nil, stringContentNode))
+		results.PushBack(candidate.CreateReplacement(stringContentNode))
 	}
 	return context.ChildContext(results), nil
 }
@@ -85,7 +87,7 @@ func decodeOperator(d *dataTreeNavigator, context Context, expressionNode *Expre
 		//first node is a doc
 		node := unwrapDoc(&dataBucket)
 
-		results.PushBack(candidate.CreateChild(nil, node))
+		results.PushBack(candidate.CreateReplacement(node))
 	}
 	return context.ChildContext(results), nil
 }
