@@ -138,25 +138,37 @@ func withEntriesOperator(d *dataTreeNavigator, context Context, expressionNode *
 		return Context{}, err
 	}
 
-	//run expression against entries
-	// splat toEntries and pipe it into Rhs
-	splatted, err := splat(d, toEntries, traversePreferences{})
-	if err != nil {
-		return Context{}, err
-	}
+	var results = list.New()
 
-	result, err := d.GetMatchingNodes(splatted, expressionNode.Rhs)
-	log.Debug("expressionNode.Rhs %v", expressionNode.Rhs.Operation.OperationType)
-	log.Debug("result %v", result)
-	if err != nil {
-		return Context{}, err
-	}
+	for el := toEntries.MatchingNodes.Front(); el != nil; el = el.Next() {
+		//run expression against entries
+		// splat toEntries and pipe it into Rhs
+		splatted, err := splat(d, context.SingleChildContext(el.Value.(*CandidateNode)), traversePreferences{})
+		if err != nil {
+			return Context{}, err
+		}
+
+		result, err := d.GetMatchingNodes(splatted, expressionNode.Rhs)
+		log.Debug("expressionNode.Rhs %v", expressionNode.Rhs.Operation.OperationType)
+		log.Debug("result %v", result)
+		if err != nil {
+			return Context{}, err
+		}
+
+		selfExpression := &ExpressionNode{Operation: &Operation{OperationType: selfReferenceOpType}}
+		collected, err := collectTogether(d, result, selfExpression)
+		if err != nil {
+			return Context{}, err
+		}
+
+		fromEntries, err := fromEntriesOperator(d, context.SingleChildContext(collected), expressionNode)
+		if err != nil {
+			return Context{}, err
+		}
+		results.PushBackList(fromEntries.MatchingNodes)
 
-	collected, err := collectOperator(d, result, expressionNode)
-	if err != nil {
-		return Context{}, err
 	}
 
 	//from_entries on the result
-	return fromEntriesOperator(d, collected, expressionNode)
+	return context.ChildContext(results), nil
 }
