@@ -17,22 +17,25 @@ func selectOperator(d *dataTreeNavigator, context Context, expressionNode *Expre
 			return Context{}, err
 		}
 
-		// grab the first value
-		first := rhs.MatchingNodes.Front()
+		// find any truthy node
+		var errDecoding error
+		includeResult := false
 
-		if first != nil {
-			result := first.Value.(*CandidateNode)
-			log.Debugf("result %v", NodeToString(result))
-			includeResult, errDecoding := isTruthy(result)
+		for resultEl := rhs.MatchingNodes.Front(); resultEl != nil; resultEl = resultEl.Next() {
+			result := resultEl.Value.(*CandidateNode)
+			includeResult, errDecoding = isTruthy(result)
 			log.Debugf("isTruthy %v", includeResult)
 			if errDecoding != nil {
 				return Context{}, errDecoding
 			}
-
 			if includeResult {
-				results.PushBack(candidate)
+				break
 			}
 		}
+
+		if includeResult {
+			results.PushBack(candidate)
+		}
 	}
 	return context.ChildContext(results), nil
 }
