@@ -142,8 +142,8 @@ e: >-
 		document:   `a: cat`,
 		expression: `.. | style`,
 		expected: []string{
-			"D0, P[], (!!str)::\"\"\n",
-			"D0, P[a], (!!str)::\"\"\n",
+			"D0, P[], (!!str)::\n",
+			"D0, P[a], (!!str)::\n",
 		},
 	},
 }
@@ -152,5 +152,5 @@ func TestStyleOperatorScenarios(t *testing.T) {
 	for _, tt := range styleOperatorScenarios {
 		testScenario(t, &tt)
 	}
-	documentScenarios(t, "Style", styleOperatorScenarios)
+	documentScenarios(t, "style", styleOperatorScenarios)
 }
